.. _examples_modelling_cbed_distortion_estimation_sec:

Examples of distortion estimation of CBED patterns
==================================================

Below are links to some code examples of "actions" and Jupyter notebooks that
are related to the estimation of distortion in CBED patterns, using deep
learning.

The majority of the data presented in Ref. [Fitzpatrick1]_ can be reproduced by
running all of the examples listed on this current page.

.. toctree::

   estimation/generate_ml_datasets_for_training_and_validation.rst
   estimation/combine_ml_datasets_for_training_and_validation_then_split.rst
   estimation/train_ml_model_set.rst
   estimation/generate_ml_datasets_for_ml_model_test_set_1.rst
   estimation/combine_ml_datasets_for_ml_model_test_set_1.rst
   estimation/run_ml_model_test_set_1.rst
   estimation/run_rgm_test_set_1.rst
   estimation/analyzing_ml_model_training_results.rst
   estimation/analyzing_ml_model_testing_results.rst
   estimation/correcting_distortion_in_saed_data.rst
